@@ -43,10 +43,10 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
 
       elif self.tagTrain and tag == 'a':
          self.tagTrainA = True
-      
+
       elif tag=='ul' and dict(attrs).has_key('class') and dict(attrs)['class']=='error_list':
          self.tagError = True
-         
+
       elif self.tagError and tag=='li':
          self.tagErrorLi = True
 
@@ -70,7 +70,7 @@ class TableParserRERratp(Extractor, HTMLParser.HTMLParser):
          # On raccourcit 'Train a l'approche' et 'Train a quai'
          heure = heure.replace('Train ', '')
          self.liste_horaire.append(heure)
-       
+
       if self.tagErrorLi:
          self.error += data.strip()
 
@@ -99,7 +99,7 @@ class ExtractorRERratp(TableParserRERratp):
       self.ligne = ligne.ligne
       self.sens = ligne.direction
       lineTitle = ( ('R', self.ligne, 32), self.depart)
-      self.trajetModel.setIconTitle( lineTitle )
+      self.rideModel.setIconTitle( lineTitle )
 
       urlMobi = 'http://www.ratp.fr/horaires/fr/ratp/rer/prochains_passages/R%s/%s/%s'
       self.url = urlMobi%(self.ligne, self.station, self.sens)
