@@ -79,6 +79,7 @@ class TrainTrainView(QtGui.QMainWindow):
       self.model.RemoveRideModel(view.model)
       self.vLayout.removeWidget(view)
       del self.views[view.model.id]
+      view.setParent(None)
 
    def CreateAppLayouts(self):
       DebugLog("TrainTrainView::CreateAppLayouts")
@@ -109,6 +110,9 @@ class TrainTrainView(QtGui.QMainWindow):
       self.scrollArea.setWidgetResizable(True)
 
       self.scrollAreaWidgetContents = QtGui.QWidget(self.scrollArea)
+      self.scrollArea.setWidget(self.scrollAreaWidgetContents)
+      self.scrollAreaWidgetContents.setObjectName('scroll')
+
       self.vLayout = QtGui.QVBoxLayout()
       self.vLayout.setSpacing(0)
       self.vLayout.setMargin(0)
@@ -119,29 +123,32 @@ class TrainTrainView(QtGui.QMainWindow):
       self.tLayout.setMargin(0)
       self.tLayout.addLayout(self.vLayout)
       addButton = QtGui.QPushButton('Ajouter un trajet')
-      self.tLayout.addWidget(addButton)
       addButton.clicked.connect(self.AddRide)
-      addButton.setDefault(True)
-      addButton.setStyleSheet('background-color:#2684DB; color: #fff; margin: 5px; padding: 5px;')
+
+      self.tLayout.addWidget(addButton)
+#      addButton.setStyleSheet('background-color:#2684DB; color: #fff; ')
 
       self.scrollAreaWidgetContents.setLayout( self.tLayout )
-      self.scrollAreaWidgetContents.setStyleSheet("background: #fff; margin: 0; padding: 0;")
+      self.scrollAreaWidgetContents.setStyleSheet("QWidget#scroll { background: #fff; margin: 0; padding: 0;} ")
 
-      self.scrollArea.setWidget(self.scrollAreaWidgetContents)
+#      self.tabW = QtGui.QTabWidget()
+#      self.tabW.setTabPosition(QtGui.QTabWidget.East)
+#      self.tabW.addTab(self.scrollArea, 'Mes Trains')
+#      self.tabW.addTab(addButton, 'Horaire')
+
+#      self.setCentralWidget(self.tabW) #self.scrollArea)
       self.setCentralWidget(self.scrollArea)
 
-      self.firstTime = True
       self.connect(self.model, QtCore.SIGNAL('extracted'), self.Extracted, QtCore.Qt.QueuedConnection)
-
       self.connect(QtGui.QApplication.desktop(), QtCore.SIGNAL('resized(int)'), self.Resized)
 
    def Resized(self, val):
       desktop = QtGui.QApplication.desktop()
 
-      # if desktop.screenGeometry().width() > desktop.screenGeometry().height():
-         # print "<p align=\"center\">In Landscape Mode</p>"
-      # else:
-         # print "<p align=\"center\">In Portrait Mode</p>"
+      if desktop.screenGeometry().width() > desktop.screenGeometry().height():
+         self.tabW.setTabPosition(QtGui.QTabWidget.East)
+      else:
+         self.tabW.setTabPosition(QtGui.QTabWidget.South)
 
    def Update(self):
       DebugLog("TrainTrainView::Update")
